betweenness_network: Build and Visualize a Network with Edge Betweenness

View source: R/betweenness.R

betweenness_networkR Documentation

Build and Visualize a Network with Edge Betweenness

Description

This function builds a network from a transition matrix in a tna object and computes edge betweenness for the network.

Usage

betweenness_network(x, directed)

## S3 method for class 'tna'
betweenness_network(x, directed)

Arguments

x

A tna object.

directed

A logical value. If TRUE, the network is considered directed.

Value

A tna object where the edge weights are edge betweenness values.

See Also

Centrality measure functions centralities(), plot.group_tna_centralities(), plot.tna_centralities(), print.group_tna_centralities(), print.tna_centralities()

Examples

model <- tna(group_regulation)
betweenness_network(model)


tna documentation built on Nov. 5, 2025, 7:14 p.m.