| build_model | R Documentation |
Construct a transition network analysis (TNA) model from sequence data. The function takes a data set of sequence of events or states as input and builds a TNA model. It extracts the edge weights and initial probabilities from the data along with the state labels. The function also accepts weight matrices and initial state probabilities directly.
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
## Default S3 method:
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
## S3 method for class 'matrix'
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
## S3 method for class 'stslist'
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
## S3 method for class 'data.frame'
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
## S3 method for class 'tna_data'
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
## S3 method for class 'tsn'
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
## S3 method for class 'tsn_ews'
build_model(
x,
type = "relative",
scaling = character(0L),
cols = tidyselect::everything(),
params = list(),
inits,
begin_state,
end_state
)
tna(x, ...)
ftna(x, ...)
ctna(x, ...)
atna(x, ...)
tsn(x, ...)
x |
A |
type |
A
|
scaling |
A
|
cols |
An |
params |
A
|
inits |
An optional |
begin_state |
A |
end_state |
A |
... |
Ignored. For the |
An object of class tna which is a list containing the
following elements:
weights: An adjacency matrix of the model (weight matrix).
inits: A numeric vector of initial values for each state.
For matrix type x, this element will be NULL if inits is not
directly provided
labels: A character vector of the state labels, or NULL if
there are no labels.
data: The original sequence data that has been converted to an
internal format used by the package when x is a stslist or a
data.frame object. Otherwise NULL.
Basic functions
hist.group_tna(),
hist.tna(),
plot.group_tna(),
plot.tna(),
plot_frequencies(),
plot_frequencies.group_tna(),
plot_mosaic(),
plot_mosaic.group_tna(),
plot_mosaic.tna_data(),
print.group_tna(),
print.summary.group_tna(),
print.summary.tna(),
print.tna(),
summary.group_tna(),
summary.tna(),
tna-package
model <- build_model(group_regulation)
print(model)
model <- tna(group_regulation)
model <- ftna(group_regulation)
model <- ctna(group_regulation)
model <- atna(group_regulation)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.