| cliques | R Documentation |
This function identifies cliques of a specified size in a transition network.
It searches for cliques, i.e., complete subgraphs where every pair of nodes
is connected, of size n in the transition matrix for the specified cluster
in the tna object.
cliques(x, ...)
## S3 method for class 'tna'
cliques(x, size = 2, threshold = 0, sum_weights = FALSE, ...)
## S3 method for class 'group_tna'
cliques(x, size = 2, threshold = 0, sum_weights = FALSE, ...)
x |
A |
... |
Ignored. |
size |
An |
threshold |
A |
sum_weights |
A |
A tna_cliques object which is a list of two elements:
weights is a matrix of the edge weights in the clique.
inits is a numeric vector of initial weights for the clique.
If x is a group_tna object, a group_tna_cliques object is returned
instead, which is a list or tna_cliques objects.
Clique-related functions
plot.group_tna_cliques(),
plot.tna_cliques(),
print.group_tna_cliques(),
print.tna_cliques()
model <- tna(group_regulation)
# Find 2-cliques (dyads)
cliq <- cliques(model, size = 2)
model <- group_tna(engagement_mmm)
cliques(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.