| compare_sequences | R Documentation |
Performs comprehensive sequence comparison analysis between groups. All patterns of the sequences (subsequences of specific length) are extracted from all sequences in each group. For two groups, the proportions of the patterns between the groups are compared with a z-test for proportions. For more than two groups, the Chi-squared test is applied. Both tests are applied within patterns of the same length.
compare_sequences(x, ...)
## Default S3 method:
compare_sequences(x, group, sub, min_freq = 5L, correction = "bonferroni", ...)
## S3 method for class 'group_tna'
compare_sequences(x, sub, min_freq = 5L, correction = "bonferroni", ...)
x |
A |
... |
Not used. |
group |
A |
sub |
An |
min_freq |
An |
correction |
A |
A tna_sequence_comparison object, which is a data.frame with
columns giving the names of the pattern, pattern frequencies, pattern
proportions (within patterns of the same length), test statistic values
and p-values of the tests.
Model comparison functions
compare(),
compare.group_tna(),
plot.tna_comparison(),
plot.tna_sequence_comparison(),
plot_compare(),
plot_compare.group_tna(),
print.tna_comparison(),
print.tna_sequence_comparison()
group <- c(rep("High", 1000), rep("Low", 1000))
comp <- compare_sequences(group_regulation, group)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.