| estimate_cs | R Documentation |
Estimates the stability of centrality measures in a network using subset sampling without replacement. It allows for dropping varying proportions of cases and calculates correlations between the original centralities and those computed using sampled subsets.
estimate_cs(
x,
loops,
normalize,
measures,
iter,
method,
drop_prop,
threshold,
certainty,
progressbar
)
estimate_centrality_stability(
x,
loops,
normalize,
measures,
iter,
method,
drop_prop,
threshold,
certainty,
progressbar
)
## S3 method for class 'tna'
estimate_cs(
x,
loops = FALSE,
normalize = FALSE,
measures = c("InStrength", "OutStrength", "Betweenness"),
iter = 1000,
method = "pearson",
drop_prop = seq(0.1, 0.9, by = 0.1),
threshold = 0.7,
certainty = 0.95,
progressbar = FALSE
)
## S3 method for class 'tna'
estimate_centrality_stability(
x,
loops = FALSE,
normalize = FALSE,
measures = c("InStrength", "OutStrength", "Betweenness"),
iter = 1000,
method = "pearson",
drop_prop = seq(0.1, 0.9, by = 0.1),
threshold = 0.7,
certainty = 0.95,
progressbar = FALSE
)
## S3 method for class 'group_tna'
estimate_cs(
x,
loops = FALSE,
normalize = FALSE,
measures = c("InStrength", "OutStrength", "Betweenness"),
iter = 1000,
method = "pearson",
drop_prop = seq(0.1, 0.9, by = 0.1),
threshold = 0.7,
certainty = 0.95,
progressbar = FALSE
)
## S3 method for class 'group_tna'
estimate_centrality_stability(
x,
loops = FALSE,
normalize = FALSE,
measures = c("InStrength", "OutStrength", "Betweenness"),
iter = 1000,
method = "pearson",
drop_prop = seq(0.1, 0.9, by = 0.1),
threshold = 0.7,
certainty = 0.95,
progressbar = FALSE
)
x |
A |
loops |
A |
normalize |
A |
measures |
A |
iter |
An |
method |
A |
drop_prop |
A |
threshold |
A |
certainty |
A |
progressbar |
A |
The function works by repeatedly resampling the data, dropping varying proportions of cases, and calculating centrality measures on the subsets. The correlation between the original centralities and the resampled centralities is calculated for each drop proportion. The stability of each centrality measure is then summarized using a centrality stability (CS) coefficient, which represents the proportion of dropped cases at which the correlations drop below a given threshold (default 0.7).
The results can be visualized by plotting the output object showing the stability of the centrality measures across different drop proportions, along with confidence intervals. The CS-coefficients are displayed in the subtitle.
A tna_stability object which is a list with an element for each
measure with the following elements:
cs_coefficient: The centrality stability (CS) coefficient
of the measure.
correlations: A matrix of correlations between the original
centrality and the resampled centralities for each drop proportion.
If x is a group_tna object, a group_tna_stability object is returned
instead, which is a list of tna_stability objects.
Validation functions
bootstrap(),
deprune(),
permutation_test(),
permutation_test.group_tna(),
plot.group_tna_bootstrap(),
plot.group_tna_permutation(),
plot.group_tna_stability(),
plot.tna_bootstrap(),
plot.tna_permutation(),
plot.tna_stability(),
print.group_tna_bootstrap(),
print.group_tna_permutation(),
print.group_tna_stability(),
print.summary.group_tna_bootstrap(),
print.summary.tna_bootstrap(),
print.tna_bootstrap(),
print.tna_permutation(),
print.tna_stability(),
prune(),
pruning_details(),
reprune(),
summary.group_tna_bootstrap(),
summary.tna_bootstrap()
model <- tna(group_regulation)
# Small number of iterations and drop proportions for CRAN
estimate_cs(
model,
drop_prop = seq(0.3, 0.9, by = 0.2),
measures = c("InStrength", "OutStrength"),
iter = 10
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.