| plot.group_tna | R Documentation |
Plots a transition network of each cluster using qgraph.
## S3 method for class 'group_tna'
plot(x, title, which, ...)
x |
A |
title |
A title for each plot. It can be a single string (the same one will be used for all plots) or a list (one per group) |
which |
An optional |
... |
Arguments passed on to
|
NULL (invisibly).
Basic functions
build_model(),
hist.group_tna(),
hist.tna(),
plot.tna(),
plot_frequencies(),
plot_frequencies.group_tna(),
plot_mosaic(),
plot_mosaic.group_tna(),
plot_mosaic.tna_data(),
print.group_tna(),
print.summary.group_tna(),
print.summary.tna(),
print.tna(),
summary.group_tna(),
summary.tna(),
tna-package
model <- group_model(engagement_mmm)
plot(model, which = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.