# S3 method for group_tna_cliques
plot(x, title, ...)
Value
A list (invisibly) with one element per cluster. Each element
contains a cograph_network plot when only one clique is present per
cluster, otherwise the element is NULL.
Arguments
x
A group_tna_cliques object.
title
A character vector of titles to use for each plot.