Learn R Programming

tna (version 1.3.1)

plot.tna_cliques: Plot Cliques of a TNA Network

Description

Plot Cliques of a TNA Network

Usage

# S3 method for tna_cliques
plot(x, n = 6, first = 1, show_loops = FALSE, colors, ask = TRUE, ...)

Value

NULL (invisibly).

Arguments

x

A tna_cliques object.

n

An integer defining the maximum number of cliques to show. The defaults is 6.

first

An integer giving the index of the first clique to show. The default index is 1.

show_loops

A logical value indicating whether to include loops in the plots or not.

colors

Optional character vector of colors values to use for the nodes.

ask

A logical value. When TRUE, show plots one by one and asks to plot the next plot in interactive mode.

...

Ignored.

See Also

Clique-related functions cliques(), plot.group_tna_cliques(), print.group_tna_cliques(), print.tna_cliques()

Examples

Run this code
model <- tna(group_regulation)
cliq <- cliques(model, size = 2)
plot(cliq, n = 1, ask = FALSE)

Run the code above in your browser using DataLab