plot_associations: Plot an Association Network

plot_associationsR Documentation

Plot an Association Network

Description

Plot an Association Network

Usage

plot_associations(x, ...)

## S3 method for class 'tna'
plot_associations(x, edge.color, ...)

Arguments

x

A tna object.

...

Additional arguments passed to plot_model().

edge.color

An optional character vector of colors for the edges. By default, the colors are specified by the magnitude of the standardized residual.

Value

A qgraph plot of the network.

Examples

model <- ftna(group_regulation)
plot_associations(model)


tna documentation built on Nov. 5, 2025, 7:14 p.m.