Learn R Programming

tna (version 1.3.1)

plot_compare.group_tna: Plot the Difference Network Between Two Groups

Description

Plot the Difference Network Between Two Groups

Usage

# S3 method for group_tna
plot_compare(x, i = NULL, j = NULL, ...)

Value

A cograph_network object displaying the difference network between the two clusters

Arguments

x

A group_tna object.

i

An integer index or the name of the principal cluster as a character string. When NULL, defaults are chosen automatically (see cograph::plot_compare()).

j

An integer index or the name of the secondary cluster as a character string. When NULL, defaults are chosen automatically (see cograph::plot_compare()).

...

Additional arguments passed to cograph::plot_compare().

See Also

Model comparison functions compare(), compare.group_tna(), compare_sequences(), plot.tna_comparison(), plot.tna_sequence_comparison(), plot_compare(), print.tna_comparison(), print.tna_sequence_comparison()

Examples

Run this code
model <- group_model(engagement_mmm)
plot_compare(model)

Run the code above in your browser using DataLab