Learn R Programming

tna (version 1.3.1)

plot_model: Plot a Transition Network Model from a Matrix of Edge Weights

Description

Plot a Transition Network Model from a Matrix of Edge Weights

Usage

plot_model(x, labels, colors, ...)

Value

See plot.tna().

Arguments

x

A square matrix of edge weights.

labels

Optional character vector of node labels.

colors

An optional character vector of node colors to use.

...

Additional arguments passed to cograph::splot() or cograph::plot_htna().

Examples

Run this code
m <- matrix(rexp(25), 5, 5)
plot_model(m)

Run the code above in your browser using DataLab