| betweenness_network | R Documentation |
This function builds a network from a transition matrix in a tna object
and computes edge betweenness for the network.
betweenness_network(x, directed)
## S3 method for class 'tna'
betweenness_network(x, directed)
x |
A |
directed |
A |
A tna object where the edge weights are edge betweenness values.
Centrality measure functions
centralities(),
plot.group_tna_centralities(),
plot.tna_centralities(),
print.group_tna_centralities(),
print.tna_centralities()
model <- tna(group_regulation)
betweenness_network(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.