Learn R Programming

tna (version 1.3.1)

betweenness_network: Build and Visualize a Network with Edge Betweenness

Description

This function builds a network from a transition matrix in a tna object and computes edge betweenness for the network.

Usage

betweenness_network(x, directed = TRUE, invert = TRUE)

# S3 method for tna betweenness_network(x, directed = TRUE, invert = TRUE)

Value

A tna object where the edge weights are edge betweenness values.

Arguments

x

A tna object.

directed

A logical value. If TRUE, the network is considered directed.

invert

A logical value indicating whether the weights should be inverted for distance-based measures. The default is TRUE.

See Also

Centrality measure functions centralities(), plot.group_tna_centralities(), plot.tna_centralities(), print.group_tna_centralities(), print.tna_centralities()

Examples

Run this code
model <- tna(group_regulation)
betweenness_network(model)

Run the code above in your browser using DataLab