Test edge weight differences between all pairs or a subset of pairs of
a group_tna object. See permutation_test.tna() for more details.
# S3 method for group_tna
permutation_test(
x,
groups,
adjust = "none",
iter = 1000,
paired = FALSE,
level = 0.05,
measures = character(0),
...
)A group_tna object
An integer vector or a character vector of group indices
or names, respectively, defining which groups to compare. When not provided,
all pairs are compared (the default).
A character string for the method to adjust p-values with
for multiple comparisons. The default is "none" for no adjustment.
See stats::p.adjust() for details and available adjustment methods.
An integer giving the number of permutations to perform.
The default is 1000.
A logical value. If TRUE, perform paired permutation tests;
if FALSE, perform unpaired tests. The default is FALSE.
A numeric value giving the significance level for the
permutation tests. The default is 0.05.
A character vector of centrality measures to test.
See centralities() for a list of available centrality measures.
Additional arguments passed to centralities().
Validation functions
bootstrap(),
deprune(),
estimate_cs(),
permutation_test(),
plot.group_tna_bootstrap(),
plot.group_tna_permutation(),
plot.group_tna_stability(),
plot.tna_bootstrap(),
plot.tna_permutation(),
plot.tna_stability(),
print.group_tna_bootstrap(),
print.group_tna_permutation(),
print.group_tna_stability(),
print.summary.group_tna_bootstrap(),
print.summary.tna_bootstrap(),
print.tna_bootstrap(),
print.tna_permutation(),
print.tna_stability(),
prune(),
pruning_details(),
reprune(),
summary.group_tna_bootstrap(),
summary.tna_bootstrap()
model <- group_model(engagement_mmm)
# Small number of iterations for CRAN
permutation_test(model, iter = 20)
Run the code above in your browser using DataLab