Plots a transition network of each cluster using cograph.
# S3 method for group_tna
plot(x, title, which, ...)NULL (invisibly).
A group_model object.
A title for each plot. It can be a single string (the same one will be used for all plots) or a list (one per group)
An optional integer vector of groups to plot. By default, all
groups are plotted.
Arguments passed on to plot.tna
node_listAn optional list of two character vectors that define
two mutually exclusive groups of node labels.
use_list_orderA logical value. If node_list is provided,
defines how the order of the nodes in the plot is defined. A TRUE value
uses the order in node_list. Otherwise, the nodes are ranked based on
edge weights and ordered according to the rank.
scale_nodesA character string giving the name of a centrality
measure to scale the node size by. See centralities() for valid names.
If missing (the default), uses default cograph::splot() scaling.
The value of node_size provided via ... is used as baseline size.
scaling_factorA numeric value specifying how strongly to scale
the nodes when scale_nodes is provided. Values
between 0 and 1 will result in smaller differences and values larger
than 1 will result in greater differences. The default is 0.5.
Basic functions
build_model(),
hist.group_tna(),
hist.tna(),
plot.tna(),
plot_frequencies(),
plot_frequencies.group_tna(),
plot_mosaic(),
plot_mosaic.group_tna(),
plot_mosaic.tna_data(),
print.group_tna(),
print.summary.group_tna(),
print.summary.tna(),
print.tna(),
summary.group_tna(),
summary.tna(),
tna-package
model <- group_model(engagement_mmm)
plot(model, which = 1)
Run the code above in your browser using DataLab