powered by
Plot Cliques of a TNA Network
# S3 method for tna_cliques plot(x, n = 6, first = 1, show_loops = FALSE, colors, ask = TRUE, ...)
NULL (invisibly).
NULL
A tna_cliques object.
tna_cliques
An integer defining the maximum number of cliques to show. The defaults is 6.
integer
6
An integer giving the index of the first clique to show. The default index is 1.
1
A logical value indicating whether to include loops in the plots or not.
logical
Optional character vector of colors values to use for the nodes.
character
A logical value. When TRUE, show plots one by one and asks to plot the next plot in interactive mode.
TRUE
Ignored.
Clique-related functions cliques(), plot.group_tna_cliques(), print.group_tna_cliques(), print.tna_cliques()
cliques()
plot.group_tna_cliques()
print.group_tna_cliques()
print.tna_cliques()
model <- tna(group_regulation) cliq <- cliques(model, size = 2) plot(cliq, n = 1, ask = FALSE)
Run the code above in your browser using DataLab