powered by
Plot a Transition Network Model from a Matrix of Edge Weights
plot_model(x, labels, colors, ...)
See plot.tna().
plot.tna()
A square matrix of edge weights.
matrix
Optional character vector of node labels.
character
An optional character vector of node colors to use.
Additional arguments passed to cograph::splot() or cograph::plot_htna().
cograph::splot()
cograph::plot_htna()
m <- matrix(rexp(25), 5, 5) plot_model(m)
Run the code above in your browser using DataLab